@@ -70,6 +70,12 @@
 **  _________________________________________________________________
 */
 
+/*
+ *  identify the module to SCCS `what' and RCS `ident' commands
+ */
+static char const sccsid[] = "@(#) mod_ssl/" MOD_SSL_VERSION " >";
+static char const rcsid[]  = "$Id: mod_ssl/" MOD_SSL_VERSION " $";
+
 /*
  *  the table of configuration directives we provide
  */
@@ -135,6 +141,9 @@ static command_rec ssl_config_cmds[] = {
     AP_SRV_CMD(LogLevel, TAKE1,
                "SSL logfile verbosity level "
                "(`none', `error', `warn', `info', `debug')")
+    AP_SRV_CMD(Protocol, RAW_ARGS,
+               "Enable or disable various SSL protocols"
+               "(`[+-][SSLv2|SSLv3|TLSv1] ...' - see manual)")
 
     /*
      * Per-directory context configuration directives
