@@ -289,7 +289,7 @@
  * and enabled Extended API (EAPI)
  */
 #if SSL_LIBRARY_VERSION < 0x0900
-#error "SSLeay versions below 0.9.0 are not supported"
+#error "SSLeay versions below 0.9.0 are no longer supported"
 #endif
 #ifndef EAPI
 #error "mod_ssl requires Extended API (EAPI)"
@@ -320,8 +320,7 @@ typedef struct {
 #define SSL_OPT_EXPORTCERTDATA (1<<2)
 #define SSL_OPT_FAKEBASICAUTH  (1<<3)
 #define SSL_OPT_ALL            (SSL_OPT_COMPATENVVAR|SSL_OPT_EXPORTCERTDATA|SSL_OPT_FAKEBASICAUTH)
-typedef int OptionType;
-
+typedef int ssl_opt_t;
 
 /*
  * Define the SSL Protocol options
@@ -332,7 +331,7 @@ typedef int OptionType;
 #define SSL_PROTOCOL_SSLV3 (1<<1)
 #define SSL_PROTOCOL_TLSV1 (1<<2)
 #define SSL_PROTOCOL_ALL   (SSL_PROTOCOL_SSLV2|SSL_PROTOCOL_SSLV3|SSL_PROTOCOL_TLSV1)
-typedef int ProtocolType;
+typedef int ssl_proto_t;
 
 /*
  * Define the SSL verify levels
@@ -343,7 +342,7 @@ typedef enum {
     SSL_CVERIFY_OPTIONAL        = 1,
     SSL_CVERIFY_REQUIRE         = 2,
     SSL_CVERIFY_OPTIONAL_NO_CA  = 3
-} VerifyType;
+} ssl_verify_t;
 
 /*
  * Define the SSL pass phrase dialog types
@@ -352,7 +351,7 @@ typedef enum {
     SSL_PPTYPE_UNSET   = UNSET,
     SSL_PPTYPE_BUILTIN = 0,
     SSL_PPTYPE_FILTER  = 1
-} PassPhraseType;
+} ssl_pphrase_t;
 
 /*
  * Define the Path Checking modes
@@ -361,7 +360,7 @@ typedef enum {
 #define SSL_PCM_ISREG      2
 #define SSL_PCM_ISDIR      4
 #define SSL_PCM_ISNONZERO  8
-typedef unsigned int PathCheckMode;
+typedef unsigned int ssl_pathcheck_t;
 
 /*
  * Define the SSL session cache modes and structures
@@ -371,7 +370,7 @@ typedef enum {
     SSL_SCMODE_NONE  = 0,
     SSL_SCMODE_DBM   = 1,
     SSL_SCMODE_SHM   = 2
-} SessionCacheMode;
+} ssl_scmode_t;
 
 typedef struct {
     UCHAR *ucaKey;
@@ -379,7 +378,7 @@ typedef struct {
     UCHAR *ucaData;
     int    nData;
     time_t tExpiresAt;
-} SessionCacheInfo;
+} ssl_scinfo_t;
 
 /*
  * Define the SSL mutex modes
@@ -389,7 +388,7 @@ typedef enum {
     SSL_MUTEXMODE_NONE   = 0,
     SSL_MUTEXMODE_FILE   = 1,
     SSL_MUTEXMODE_SEM    = 2
-} MutexMode;
+} ssl_mutexmode_t;
 
 /*
  * Define the SSL requirement structure
@@ -397,7 +396,7 @@ typedef enum {
 typedef struct {
     char     *cpExpr;
     ssl_expr *mpExpr;
-} SSLRequirement;
+} ssl_require_t;
 
 /*
  * Define the SSL random number generator seeding source
@@ -405,18 +404,26 @@ typedef struct {
 typedef enum {
     SSL_RSCTX_STARTUP = 1,
     SSL_RSCTX_CONNECT = 2
-} SSLRandSeedCtx;
+} ssl_rsctx_t;
 typedef enum {
     SSL_RSSRC_BUILTIN = 1,
     SSL_RSSRC_FILE    = 2,
     SSL_RSSRC_EXEC    = 3
-} SSLRandSeedSrc;
+} ssl_rssrc_t;
 typedef struct {
-    SSLRandSeedCtx  nCtx;
-    SSLRandSeedSrc  nSrc;
-    char           *cpPath;
-    int             nBytes;
-} SSLRandSeed;
+    ssl_rsctx_t  nCtx;
+    ssl_rssrc_t  nSrc;
+    char        *cpPath;
+    int          nBytes;
+} ssl_randseed_t;
+
+/*
+ * Define the structure of an ASN.1 anything
+ */
+typedef struct {
+    long int       nData;
+    unsigned char *cpData;
+} ssl_asn1_t;
 
 /*
  * Define the mod_ssl per-module configuration structure
@@ -424,25 +431,25 @@ typedef struct {
  */
 
 typedef struct {
-    pool         *pPool;
-    BOOL          bFixed;
+    pool           *pPool;
+    BOOL            bFixed;
 
     /*
      * global config data
      */
-    int           nInitCount;
+    int             nInitCount;
 
-    RSA          *pRSATmpKey;
-    int           nSessionCacheMode;
-    char         *szSessionCacheDataFile;
-    int           nMutexMode;
-    char         *szMutexFile;
-    int           nMutexFD;
-    int           nMutexSEMID;
-    array_header *aRandSeed;
+    RSA            *pRSATmpKey;
+    int             nSessionCacheMode;
+    char           *szSessionCacheDataFile;
+    ssl_mutexmode_t nMutexMode;
+    char           *szMutexFile;
+    int             nMutexFD;
+    int             nMutexSEMID;
+    array_header   *aRandSeed;
 
-    ssl_ds_table *tPublicCert;
-    ssl_ds_table *tPrivateKey;
+    ssl_ds_table   *tPublicCert;
+    ssl_ds_table   *tPrivateKey;
 
     /*
      * arbitrary global context data
@@ -468,14 +475,14 @@ typedef struct {
     FILE        *fileLogFile;
     int          nLogLevel;
     int          nVerifyDepth;
-    VerifyType   nVerifyClient;
+    ssl_verify_t nVerifyClient;
     X509        *px509Certificate;
     RSA         *prsaKey;
     SSL_CTX     *pSSLCtx;
     int          nSessionCacheTimeout;
     int          nPassPhraseDialogType;
     char        *szPassPhraseDialogPath;
-    ProtocolType nProtocol;
+    ssl_proto_t  nProtocol;
 } SSLSrvConfigRec;
 
 /*
@@ -486,11 +493,11 @@ typedef struct {
 typedef struct {
     BOOL          bSSLRequired;
     array_header *aRequirement;
-    OptionType    nOptions;
-    OptionType    nOptionsAdd;
-    OptionType    nOptionsDel;
+    ssl_opt_t     nOptions;
+    ssl_opt_t     nOptionsAdd;
+    ssl_opt_t     nOptionsDel;
     char         *szCipherSuite;
-    VerifyType    nVerifyClient;
+    ssl_verify_t  nVerifyClient;
     int           nVerifyDepth;
 #ifdef SSL_EXPERIMENTAL
     char         *szCACertificatePath;
@@ -569,9 +576,9 @@ void         ssl_scache_remove(server_rec *, SSL_SESSION *);
 void         ssl_scache_expire(server_rec *);
 char        *ssl_scache_id2sz(UCHAR *, int);
 void         ssl_scache_dbm_init(server_rec *, pool *);
-void         ssl_scache_dbm_store(server_rec *, SessionCacheInfo *);
-void         ssl_scache_dbm_retrieve(server_rec *, SessionCacheInfo *);
-void         ssl_scache_dbm_remove(server_rec *, SessionCacheInfo *);
+void         ssl_scache_dbm_store(server_rec *, ssl_scinfo_t *);
+void         ssl_scache_dbm_retrieve(server_rec *, ssl_scinfo_t *);
+void         ssl_scache_dbm_remove(server_rec *, ssl_scinfo_t *);
 void         ssl_scache_dbm_expire(server_rec *);
 
 /*  Pass Phrase Support  */
@@ -624,7 +631,7 @@ void         ssl_io_unregister(void);
 long         ssl_io_data_cb(BIO *, int, char *, int, long, long);
 
 /*  PRNG  */
-int          ssl_rand_seed(server_rec *, pool *, SSLRandSeedCtx);
+int          ssl_rand_seed(server_rec *, pool *, ssl_rsctx_t);
 
 /*  Extensions  */
 void         ssl_ext_register(void);
@@ -645,7 +652,7 @@ FILE        *ssl_util_ppopen(server_rec *, pool *, char *);
 int          ssl_util_ppopen_child(void *, child_info *);
 void         ssl_util_ppclose(server_rec *, pool *, FILE *);
 char        *ssl_util_readfilter(server_rec *, pool *, char *);
-BOOL         ssl_util_path_check(PathCheckMode, char *);
+BOOL         ssl_util_path_check(ssl_pathcheck_t, char *);
 char        *ssl_util_ptxtsub(pool *, const char *, const char *, char *);
 void         ssl_util_thread_setup(void);
 
