@@ -128,10 +128,10 @@ void ssl_config_global_create(void)
         mc->szMutexFile            = NULL;
         mc->nMutexFD               = -1;
         mc->nMutexSEMID            = -1;
-        mc->aRandSeed              = ap_make_array(pPool, 4, sizeof(SSLRandSeed));
+        mc->aRandSeed              = ap_make_array(pPool, 4, sizeof(ssl_randseed_t));
 
-        mc->tPrivateKey            = ssl_ds_table_make(pPool, sizeof(RSA *));
-        mc->tPublicCert            = ssl_ds_table_make(pPool, sizeof(X509 *));
+        mc->tPrivateKey            = ssl_ds_table_make(pPool, sizeof(ssl_asn1_t));
+        mc->tPublicCert            = ssl_ds_table_make(pPool, sizeof(ssl_asn1_t));
 
         /*
          * And push it into Apache's global context
@@ -232,7 +232,7 @@ void *ssl_config_perdir_create(pool *p, char *dir)
     SSLDirConfigRec *dc = ap_palloc(p, sizeof(SSLDirConfigRec));
 
     dc->bSSLRequired  = FALSE;
-    dc->aRequirement  = ap_make_array(p, 4, sizeof(SSLRequirement));
+    dc->aRequirement  = ap_make_array(p, 4, sizeof(ssl_require_t));
     dc->nOptions      = SSL_OPT_NONE|SSL_OPT_RELSET;
     dc->nOptionsAdd   = SSL_OPT_NONE;
     dc->nOptionsDel   = SSL_OPT_NONE;
@@ -360,7 +360,7 @@ const char *ssl_cmd_SSLRandomSeed(
 {
     SSLModConfigRec *mc = myModConfig();
     const char *err;
-    SSLRandSeed *pRS;
+    ssl_randseed_t *pRS;
 
     if ((err = ap_check_cmd_context(cmd, GLOBAL_ONLY)) != NULL)
         return err;
@@ -614,7 +614,7 @@ const char *ssl_cmd_SSLLogLevel(
 const char *ssl_cmd_SSLOptions(
     cmd_parms *cmd, SSLDirConfigRec *dc, const char *cpLine)
 {
-    OptionType opt;
+    ssl_opt_t opt;
     int first;
     char action;
     char *w;
@@ -671,7 +671,7 @@ const char *ssl_cmd_SSLRequire(
     cmd_parms *cmd, SSLDirConfigRec *dc, char *cpExpr)
 {
     ssl_expr *mpExpr;
-    SSLRequirement *pReqRec;
+    ssl_require_t *pReqRec;
 
     if ((mpExpr = ssl_expr_comp(cmd->pool, cpExpr)) == NULL)
         return ap_pstrcat(cmd->pool, "SSLRequire: ", ssl_expr_get_error(), NULL);
@@ -685,7 +685,7 @@ const char *ssl_cmd_SSLProtocol(
     cmd_parms *cmd, char *struct_ptr, const char *opt)
 {
     SSLSrvConfigRec *sc;
-    ProtocolType options, thisopt;
+    ssl_proto_t options, thisopt;
     char action;
     char *w;
 
