@@ -147,6 +147,8 @@ static char *ssl_ext_mlc_log_c(request_rec *r, char *a)
         result = "-";
     else if (strcmp(a, "errstr") == 0)
         result = ap_ctx_get(r->connection->client->ctx, "ssl::verify::error");
+    if (result != NULL && result[0] == NUL)
+        result = NULL;
     return result;
 }
 
@@ -161,6 +163,8 @@ static char *ssl_ext_mlc_log_x(request_rec *r, char *a)
     result = NULL;
     if (ap_ctx_get(r->connection->client->ctx, "ssl") != NULL)
         result = ssl_var_lookup(r->pool, r->server, r->connection, r, a);
+    if (result != NULL && result[0] == NUL)
+        result = NULL;
     return result;
 }
 
