@@ -318,10 +318,9 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
     SSLModConfigRec *mc = myModConfig();
     int nVerify;
     char *cpVHostID;
-    RSA **ppRSA;
-    X509 **ppX509;
     SSL_CTX *ctx;
     STACK *skCAList;
+    ssl_asn1_t *asn1;
     char *cp;
 
     /*
@@ -450,25 +449,24 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
      */
     ssl_log(s, SSL_LOG_TRACE,
             "Init: (%s) Configuring server certificate", cpVHostID);
-    if ((ppX509 = (X509 **)ssl_ds_table_get(mc->tPublicCert,
-                                            cpVHostID)) == NULL) {
+    if ((asn1 = (ssl_asn1_t *)ssl_ds_table_get(mc->tPublicCert, cpVHostID)) == NULL) {
         ssl_log(s, SSL_LOG_ERROR,
                 "Init: (%s) Ops, can't find server certificate?!", cpVHostID);
         ssl_die();
     }
-    sc->px509Certificate = *ppX509;
+    sc->px509Certificate = d2i_X509(NULL, &(asn1->cpData), asn1->nData);
 
     /*
      *  Configure server private key
      */
     ssl_log(s, SSL_LOG_TRACE,
             "Init: (%s) Configuring server private key", cpVHostID);
-    if ((ppRSA = (RSA **)ssl_ds_table_get(mc->tPrivateKey, cpVHostID)) == NULL) {
+    if ((asn1 = (ssl_asn1_t *)ssl_ds_table_get(mc->tPrivateKey, cpVHostID)) == NULL) {
         ssl_log(s, SSL_LOG_ERROR,
                 "Init: (%s) Ops, can't find server private key?!", cpVHostID);
         ssl_die();
     }
-    sc->prsaKey = *ppRSA;
+    sc->prsaKey = d2i_RSAPrivateKey(NULL, &(asn1->cpData), asn1->nData);
 
     return;
 }
