@@ -119,12 +119,11 @@ void ssl_io_unregister(void)
 static int ssl_io_hook_read(BUFF *fb, char *buf, int len)
 {
     SSL *ssl;
+    conn_rec *c;
     int rc;
 
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_read(ssl, buf, len);
-        if (rc < 0)
-            rc = -1;
         /*
          * Simulate an EINTR in case SSLeay wants to read more.
          * (This is usually the case when the client forces an SSL
@@ -132,6 +131,19 @@ static int ssl_io_hook_read(BUFF *fb, char *buf, int len)
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_READ)
             errno = EINTR;
+        /*
+         * Log SSL errors
+         */
+        if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_SSL) {
+            c = (conn_rec *)SSL_get_app_data(ssl);
+            ssl_log(c->server, SSL_LOG_ERROR|SSL_ADD_SSLERR,
+                    "SSL error on reading data");
+        }
+        /*
+         * read(2) returns only the generic error number -1
+         */
+        if (rc < 0)
+            rc = -1;
     }
     else
         rc = read(fb->fd_in, buf, len);
@@ -141,17 +153,29 @@ static int ssl_io_hook_read(BUFF *fb, char *buf, int len)
 static int ssl_io_hook_write(BUFF *fb, char *buf, int len)
 {
     SSL *ssl;
+    conn_rec *c;
     int rc;
 
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_write(ssl, buf, len);
-        if (rc < 0)
-            rc = -1;
         /*
          * Simulate an EINTR in case SSLeay wants to write more.
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
             errno = EINTR;
+        /*
+         * Log SSL errors
+         */
+        if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_SSL) {
+            c = (conn_rec *)SSL_get_app_data(ssl);
+            ssl_log(c->server, SSL_LOG_ERROR|SSL_ADD_SSLERR,
+                    "SSL error on writing data");
+        }
+        /*
+         * write(2) returns only the generic error number -1
+         */
+        if (rc < 0)
+            rc = -1;
     }
     else
         rc = write(fb->fd, buf, len);
@@ -165,17 +189,29 @@ static int SSL_writev(SSL *, const struct iovec *, int);
 static int ssl_io_hook_writev(BUFF *fb, const struct iovec *iov, int iovcnt)
 {
     SSL *ssl;
+    conn_rec *c;
     int rc;
 
     if ((ssl = ap_ctx_get(fb->ctx, "ssl")) != NULL) {
         rc = SSL_writev(ssl, iov, iovcnt);
-        if (rc < 0)
-            rc = -1;
         /*
          * Simulate an EINTR in case SSLeay wants to write more.
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
             errno = EINTR;
+        /*
+         * Log SSL errors
+         */
+        if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_SSL) {
+            c = (conn_rec *)SSL_get_app_data(ssl);
+            ssl_log(c->server, SSL_LOG_ERROR|SSL_ADD_SSLERR,
+                    "SSL error on writing data");
+        }
+        /*
+         * writev(2) returns only the generic error number -1
+         */
+        if (rc < 0)
+            rc = -1;
     }
     else
         rc = writev(fb->fd, iov, iovcnt);
