@@ -568,8 +568,8 @@ int ssl_hook_Access(request_rec *r)
     SSL *ssl;
     SSL_CTX *ctx;
     array_header *apRequirement;
-    SSLRequirement *pRequirements;
-    SSLRequirement *pRequirement;
+    ssl_require_t *pRequirements;
+    ssl_require_t *pRequirement;
     char *cp;
     int ok;
     int i;
@@ -589,7 +589,7 @@ int ssl_hook_Access(request_rec *r)
     dc  = myDirConfig(r);
     sc  = mySrvConfig(r->server);
     ssl = ap_ctx_get(r->connection->client->ctx, "ssl");
-	if (ssl != NULL)
+    if (ssl != NULL)
         ctx = SSL_get_SSL_CTX(ssl);
 
     /*
@@ -611,18 +611,18 @@ int ssl_hook_Access(request_rec *r)
     /*
      * Support for per-directory SSL connection parameters.  
      * 
-     * This is implemented by forcing a SSL renegotation with the reconfigured
-     * parameter suite. But Apache's internal API processing makes our life
-     * very hard, because when internal sub-requests occur we nevertheless
-     * should avoid multiple unnecessary SSL handshakes (they need network I/O
-     * and time to perform). But the optimization for filtering out the
-     * unnecessary handshakes isn't such obvious.  Especially because while
-     * Apache is in its sub-request processing the client could force
-     * additional handshakes, too. And these take place perhaps without our
-     * notice. So the only possibility is to ask SSLeay/OpenSSL whether the
-     * renegotiation has to be performed or not. It has to performed when the
-     * parameters which were previously known are not those we've now
-     * reconfigured.
+     * This is implemented by forcing an SSL renegotiation with the
+     * reconfigured parameter suite. But Apache's internal API processing
+     * makes our life very hard, because when internal sub-requests occur we
+     * nevertheless should avoid multiple unnecessary SSL handshakes (they
+     * need network I/O and time to perform). But the optimization for
+     * filtering out the unnecessary handshakes isn't such obvious.
+     * Especially because while Apache is in its sub-request processing the
+     * client could force additional handshakes, too. And these take place
+     * perhaps without our notice. So the only possibility is to ask
+     * SSLeay/OpenSSL whether the renegotiation has to be performed or not. It
+     * has to performed when some parameters which were previously known (by
+     * us) are not those we've now reconfigured (as known by SSLeay/OpenSSL).
      */
     renegotiate = FALSE;
 #ifdef SSL_EXPERIMENTAL
@@ -666,6 +666,19 @@ int ssl_hook_Access(request_rec *r)
             sk_free(skCipherOld);
     }
 
+    /*
+     * override of SSLVerifyDepth:
+     * This is handled by us manually inside the verify callback
+     * function and not by SSLeay internally. And our function is
+     * aware of both the per-server and per-directory contexts.
+     * All we have to do is to force the renegotiation when the
+     * maximum allowed depth is changed.
+     */
+    if (dc->nVerifyDepth != UNSET) {
+        if (dc->nVerifyDepth != sc->nVerifyDepth)
+            renegotiate = TRUE;
+    }
+
     /* 
      * override of SSLVerifyClient
      */
@@ -686,19 +699,6 @@ int ssl_hook_Access(request_rec *r)
             renegotiate = TRUE;
     }
 
-    /*
-     * override of SSLVerifyDepth:
-     * This is handled by us manually inside the verify callback
-     * function and not by SSLeay internally. And our function is
-     * aware of both the per-server and per-directory contexts.
-     * All we have to do is to force the renegotiation when the
-     * maximum allowed depth is changed.
-     */
-    if (dc->nVerifyDepth != UNSET) {
-        if (dc->nVerifyDepth != sc->nVerifyDepth)
-            renegotiate = TRUE;
-    }
-
     /*
      *  override SSLCACertificateFile & SSLCACertificatePath
      *  This is tagged experimental because it has to use an ugly kludge: We
@@ -817,7 +817,7 @@ int ssl_hook_Access(request_rec *r)
      * Check SSLRequire boolean expressions
      */
     apRequirement = dc->aRequirement;
-    pRequirements  = (SSLRequirement *)apRequirement->elts;
+    pRequirements  = (ssl_require_t *)apRequirement->elts;
     for (i = 0; i < apRequirement->nelts; i++) {
         pRequirement = &pRequirements[i];
         ok = ssl_expr_exec(r, pRequirement->mpExpr);
@@ -1014,8 +1014,10 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
             "Certificate Verification: depth: %d, subject: %s, issuer: %s",
             errdepth, cp != NULL ? cp : "-unknown-",
             cp2 != NULL ? cp2 : "-unknown");
-    free(cp);
-    free(cp2);
+    if (cp)
+        free(cp);
+    if (cp2)
+        free(cp2);
 
     /*
      * Check for optionally acceptable non-verifiable issuer situation
