@@ -83,10 +83,10 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
     server_rec *pServ;
     char *cpVHostID;
     char szPath[MAX_STRING_LEN];
+    ssl_asn1_t *asn1;
+    unsigned char *ucp;
     RSA *pRSAKey;
-    RSA **ppRSAKey;
     X509 *pX509Cert;
-    X509 **ppX509Cert;
     FILE *fp;
     BOOL bReadable;
     ssl_ds_array *aPassPhrase;
@@ -151,8 +151,15 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
          * certificate is actually used to configure mod_ssl's per-server
          * configuration structures).
          */
-        ppX509Cert = ssl_ds_table_push(mc->tPublicCert, cpVHostID);
-        *ppX509Cert = pX509Cert;
+        asn1 = (ssl_asn1_t *)ssl_ds_table_push(mc->tPublicCert, cpVHostID);
+        asn1->nData  = i2d_X509(pX509Cert, NULL);
+        asn1->cpData = ap_palloc(mc->pPool, asn1->nData);
+        ucp = asn1->cpData; i2d_X509(pX509Cert, &ucp); /* 2nd arg increments */
+
+        /*
+         * Free the X509 structure
+         */
+        X509_free(pX509Cert);
 
         /*
          * Read in the private key: This is the non-trivial part, because the
@@ -286,9 +293,19 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
 
         /*
          * Insert private key into the global module configuration
+         * (we convert it to a stand-alone DER byte sequence
+         * because the SSL library uses static variables inside a
+         * RSA structure which do not survive DSO reloads!)
          */
-        ppRSAKey = ssl_ds_table_push(mc->tPrivateKey, cpVHostID);
-        *ppRSAKey = pRSAKey;
+        asn1 = (ssl_asn1_t *)ssl_ds_table_push(mc->tPrivateKey, cpVHostID);
+        asn1->nData  = i2d_RSAPrivateKey(pRSAKey, NULL);
+        asn1->cpData = ap_palloc(mc->pPool, asn1->nData);
+        ucp = asn1->cpData; i2d_RSAPrivateKey(pRSAKey, &ucp); /* 2nd arg increments */
+
+        /*
+         * Free the RSA structure
+         */
+        RSA_free(pRSAKey);
     }
 
     /*
