@@ -244,7 +244,7 @@ char *ssl_util_readfilter(server_rec *s, pool *p, char *cmd)
     return buf;
 }
 
-BOOL ssl_util_path_check(PathCheckMode pcm, char *path)
+BOOL ssl_util_path_check(ssl_pathcheck_t pcm, char *path)
 {
     struct stat sb;
 
