@@ -82,21 +82,15 @@
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
-#ifdef BSD42
-#include <sys/file.h>
-#else
 #include <fcntl.h>
-#include <memory.h>
-#endif
 #include <errno.h>
 #include <string.h>
-
 #ifdef __STDC__
 #include <stddef.h>
 #endif
 
 #ifndef NULL
-#define NULL 0
+#define NULL (void *)0
 #endif
 
 /*
@@ -196,7 +190,7 @@ int mode;
                 flags = (flags & ~O_WRONLY) | O_RDWR;
         else if ((flags & 03) == O_RDONLY)
                 db->flags = DBM_RDONLY;
-#ifdef WIN32
+#if defined(OS2) || defined(MSDOS) || defined(WIN32)
         flags |= O_BINARY;
 #endif
 
@@ -613,9 +607,7 @@ register int len;
         register unsigned long n = 0;
 
 #ifdef DUFF
-
 #define HASHC   n = *str++ + 65599 * n
-
         if (len > 0) {
                 register int loop = (len + 8 - 1) >> 3;
 
@@ -681,16 +673,16 @@ int need;
 {
         register int n;
         register int off;
-        register int freeit;
+        register int avail;
         register short *ino = (short *) pag;
 
         off = ((n = ino[0]) > 0) ? ino[n] : PBLKSIZ;
-        freeit = off - (n + 1) * sizeof(short);
+        avail = off - (n + 1) * sizeof(short);
         need += 2 * sizeof(short);
 
-        debug(("free %d need %d\n", freeit, need));
+        debug(("free %d need %d\n", avail, need));
 
-        return need <= freeit;
+        return need <= avail;
 }
 
 void
@@ -809,7 +801,6 @@ datum key;
                 m = ino[i + 1] - ino[n];
 #ifdef DUFF
 #define MOVB    *--dst = *--src
-
                 if (m > 0) {
                         register int loop = (m + 8 - 1) >> 3;
 
@@ -823,12 +814,9 @@ datum key;
                         }
                 }
 #else
-#ifdef MEMMOVE
+                dst -= m;
+                src -= m;
                 memmove(dst, src, m);
-#else
-                while (m--)
-                        *--dst = *--src;
-#endif
 #endif
 /*
  * adjust offset index up
