@@ -69,9 +69,7 @@
 #ifndef SSL_UTIL_SDBM_H
 #define SSL_UTIL_SDBM_H
 
-#define SDBM
-#define DUFF
-#undef BSD42
+#define DUFF    /* go ahead and use the loop-unrolled version */
 
 #include <stdio.h>
 
@@ -174,17 +172,6 @@ extern int duppair proto((char *, datum));
 
 #define BYTESIZ         8
 
-#ifdef SVID
-#include <unistd.h>
-#endif
-
-#ifdef BSD42
-#define SEEK_SET        L_SET
-#define memset(s,c,n)   bzero(s, n)             /* only when c is zero */
-#define memcpy(s1,s2,n) bcopy(s2, s1, n)
-#define memcmp(s1,s2,n) bcmp(s1,s2,n)
-#endif
-
 /*
  * important tuning parms (hah)
  */
